@@ -4,8 +4,12 @@
 
 #include <Python.h>
 
+#if PY_MAJOR_VERSION >= 3
+#define PYTHREE
+#endif
+
 /* Summary: autopy module for displaying alerts */
-/* Description: This module contains functions for displaying cross-platform 
+/* Description: This module contains functions for displaying cross-platform
                 alert dialogs. */
 PyMODINIT_FUNC initalert(void);
 
