@@ -4,6 +4,10 @@
 
 #include <Python.h>
 
+#if PY_MAJOR_VERSION >= 3
+#define PYTHREE
+#endif
+
 /* Summary: autopy module for working with bitmaps */
 /* Description: This module defines the class `Bitmap` for accessing
                 bitmaps and searching for bitmaps on-screen.
